@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef ALBUMVIEW_H
 #define ALBUMVIEW_H
 
@@ -98,6 +82,7 @@ public:
     void SearchReturnUpdate();
     void restorePicNum();
     void updatePicNum();
+    void updateTotalLabelNum();
     void updateRightView();
     void updateAlbumView(int UID);
     void updateDeviceLeftList();
@@ -196,7 +181,9 @@ private slots:
     void onImportViewImportBtnClicked();
     void onImportFailedToView();
     void onWaitDailogTimeout();
+    void onDelayLoadMountTimeout();
     void onLeftListViewMountListWidgetClicked(const QModelIndex &index);
+    void onTrashUpdate();
 
     //接收到设备中文件列表加载完成信号
     void sltLoadMountFileList(const QString &path, QStringList fileList);
@@ -212,6 +199,8 @@ private slots:
     void onBatchSelectChanged(bool isBatchSelect);
     //默认导入路径已被销毁
     void onMonitorDestroyed(int UID);
+    //筛选条件按钮宽度变化响应槽
+    void onFilterBtnWidthChanged(int width);
 public:
     int m_iAlubmPicsNum;
     QString m_currentAlbum;
@@ -295,6 +284,8 @@ private:
     DWidget *phonetopwidget;
     bool isIgnore;
     QTimer *m_waitDailog_timer;
+    QTimer *m_delayLoadMount_timer; //延迟加载挂载路径-定时器
+    QString m_delayLoadMountPath; //延迟加载路径
     QMap<QString, bool> mountLoadStatus;
 };
 
