@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "leftlistwidget.h"
 
 #include <QDebug>
@@ -78,11 +62,18 @@ void LeftListWidget::dragEnterEvent(QDragEnterEvent *event)
 }
 
 void LeftListWidget::mousePressEvent(QMouseEvent *e)
-{
+{ 
     QModelIndex index = indexAt(e->pos());
     if (!index.isValid()) {
         emit sigMousePressIsNoValid();
     }
+
+    //屏蔽双击与重复点击
+    if (!index.isValid() || m_indexLastPress == index.row()) {
+        return;
+    }
+    m_indexLastPress = index.row();
+
     DListWidget::mousePressEvent(e);
 }
 
@@ -142,3 +133,13 @@ void LeftListWidget::SaveRename(QPoint p)
         }
     }
 }
+
+void LeftListWidget::selectionChanged(const QItemSelection &selected, const QItemSelection &deselected)
+{
+    //没有选中项，则重置m_indexLastPress
+    if (selected.indexes().length() == 0) {
+        m_indexLastPress = -1;
+    }
+
+    DListWidget::selectionChanged(selected, deselected);
+}
