@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef LEFTLISTWIDGET_H
 #define LEFTLISTWIDGET_H
 #include <DListWidget>
@@ -39,6 +23,8 @@ public:
     //重命名状态下，接收外层ListView的点击事件确认保存已修改的内容
     void SaveRename(QPoint p);
 
+    virtual void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+
 protected:
     void dragMoveEvent(QDragMoveEvent *event) Q_DECL_OVERRIDE;
     void dropEvent(QDropEvent *event) Q_DECL_OVERRIDE;
@@ -50,7 +36,9 @@ signals:
     void sigMousePressIsNoValid();
     void sigMouseMoveEvent();
     void sigMouseReleaseEvent(QModelIndex index);
-
+private:
+    //最近点击item的索引
+    int m_indexLastPress = -1;
 };
 
 #endif  // LEFTLISTWIDGET_H
