@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "dbmanager.h"
 #include "application.h"
 #include "controller/signalmanager.h"
@@ -110,7 +94,8 @@ const QList<QDateTime> DBManager::getAllTimelines() const
     QMutexLocker mutex(&m_dbMutex);
     QList<QDateTime> times;
     m_query->setForwardOnly(true);
-    if (!m_query->exec("SELECT DISTINCT Time FROM ImageTable3 ORDER BY Time DESC")) {
+    // 时间线界面按日期展示相册内容，所以从数据库筛选出日期即可，不用筛选出具体时间
+    if (!m_query->exec("SELECT DISTINCT substr(Time, 0, 11)  FROM ImageTable3 ORDER BY Time DESC")) {
         return times;
     } else {
         while (m_query->next()) {
@@ -126,9 +111,10 @@ const DBImgInfoList DBManager::getInfosByTimeline(const QDateTime &timeline) con
     DBImgInfoList infos;
     m_query->setForwardOnly(true);
 
-    bool b = m_query->prepare(QString("SELECT FilePath, FileType FROM ImageTable3 "
-                                      "WHERE Time = :Date ORDER BY Time DESC"));
-    m_query->bindValue(":Date", timeline);
+    // 使用模糊搜索获取对应日期的图片或视频
+    QString sqlStr = QString("SELECT FilePath, FileType FROM ImageTable3 "
+                             "WHERE Time LIKE \"%%1%\" ORDER BY Time DESC").arg(timeline.date().toString(Qt::ISODate));
+    bool b = m_query->prepare(sqlStr);
     if (!b || !m_query->exec()) {
     } else {
         while (m_query->next()) {
@@ -651,19 +637,23 @@ int DBManager::createAlbum(const QString &album, const QStringList &paths, Album
     m_query->setForwardOnly(true);
     if (!m_query->exec("BEGIN IMMEDIATE TRANSACTION")) {
     }
-    auto qs = QString("REPLACE INTO AlbumTable3 (AlbumId, AlbumName, PathHash, AlbumDBType, UID) VALUES (null, \"%1\", ?, %2, %3)").arg(album).arg(atype).arg(currentUID);
+    auto qs = QString("REPLACE INTO AlbumTable3 (AlbumId, AlbumName, PathHash, AlbumDBType, UID) VALUES (null, ?, ?, %1, %2)").arg(atype).arg(currentUID);
     bool b = m_query->prepare(qs);
     if (!b) {
+        qDebug() << m_query->lastError().text();
         return -1;
     }
 
     for (auto &eachHash : pathHashs) {
+        m_query->addBindValue(album);
         m_query->addBindValue(eachHash);
         if (!m_query->exec()) {
+            qDebug() << m_query->lastError().text();
         }
     }
 
     if (!m_query->exec("COMMIT")) {
+        qDebug() << m_query->lastError().text();
     }
 
     //FIXME: Don't insert the repeated filepath into the same album
@@ -697,12 +687,12 @@ bool DBManager::insertIntoAlbum(int UID, const QStringList &paths, AlbumDBType a
     }
 
     QString qs = QString("REPLACE INTO AlbumTable3 (AlbumId, AlbumName, AlbumDBType, UID, PathHash)"
-                         " VALUES (null, \"%1\", %2, %3, ?)")
-                 .arg(album).arg(atype).arg(UID);
+                         " VALUES (null, ?, %1, %2, ?)").arg(atype).arg(UID);
     if (!m_query->prepare(qs)) {
     }
     for (auto &eachPath : paths) {
         if (QFile::exists(eachPath)) { //需要路径存在才能执行添加到相册
+            m_query->addBindValue(album);
             m_query->addBindValue(utils::base::hashByString(eachPath));
             if (!m_query->exec()) {
             }
@@ -770,7 +760,13 @@ void DBManager::removeFromAlbum(int UID, const QStringList &paths, AlbumDBType a
 void DBManager::renameAlbum(int UID, const QString &newAlbum, AlbumDBType atype)
 {
     QMutexLocker mutex(&m_dbMutex);
-    if (!m_query->exec(QString("UPDATE AlbumTable3 SET AlbumName=\"%1\" WHERE UID=%2 AND AlbumDBType=%3").arg(newAlbum).arg(UID).arg(atype))) {
+
+    QString qs = QString("UPDATE AlbumTable3 SET AlbumName=:name WHERE UID=%1 AND AlbumDBType=%2").arg(UID).arg(atype);
+    if (!m_query->prepare(qs)) {
+    }
+    m_query->bindValue(":name", newAlbum);
+
+    if (!m_query->exec()) {
     }
 }
 
@@ -845,7 +841,7 @@ const DBImgInfoList DBManager::getInfosForKeyword(int UID, const QString &keywor
 
     DBImgInfoList infos;
 
-    QString queryStr = "SELECT DISTINCT i.FilePath, i.FileName, i.Dir, i.Time, i.ChangeTime, i.ImportTime "
+    QString queryStr = "SELECT DISTINCT i.FilePath, i.FileName, i.Dir, i.Time, i.ChangeTime, i.ImportTime, i.FileType "
                        "FROM ImageTable3 AS i "
                        "inner join AlbumTable3 AS a on i.PathHash=a.PathHash AND a.UID=:UID "
                        "WHERE i.FileName like '%" + keywords + "%' ORDER BY Time DESC"; //OR Time like '%" + keywords + "%' 移除按时间搜索
@@ -863,6 +859,7 @@ const DBImgInfoList DBManager::getInfosForKeyword(int UID, const QString &keywor
             info.time = m_query->value(3).toDateTime();
             info.changeTime = m_query->value(4).toDateTime();
             info.importTime = m_query->value(5).toDateTime();
+            info.itemType = ItemType(m_query->value(6).toInt());
             infos << info;
         }
     }
@@ -977,15 +974,24 @@ int DBManager::createNewCustomAutoImportPath(const QString &path, const QString
     //1.新建相册
     int UID = albumMaxUID++;
 
-    if (!m_query->exec(QString("REPLACE INTO AlbumTable3 (AlbumId, AlbumName, PathHash, AlbumDBType, UID) VALUES (null, \"%1\", \"%2\", %3, %4)")
-                       .arg(albumName).arg("7215ee9c7d9dc229d2921a40e899ec5f").arg(AutoImport).arg(UID))) {
+    QString qs1 = QString("REPLACE INTO AlbumTable3 (AlbumId, AlbumName, PathHash, AlbumDBType, UID) VALUES (null, ?, \"%1\", %2, %3)")
+                  .arg("7215ee9c7d9dc229d2921a40e899ec5f").arg(AutoImport).arg(UID);
+    if (!m_query->prepare(qs1)) {
+    }
+    m_query->addBindValue(albumName);
+
+    if (!m_query->exec()) {
         return -1;
     }
 
     //2.新建保存路径
+    QString qs2 = QString("INSERT INTO CustomAutoImportPathTable3 (UID, FullPath, AlbumName) VALUES (%1, ?, ?)").arg(UID);
+    if (!m_query->prepare(qs2)) {
+    }
+    m_query->addBindValue(path);
+    m_query->addBindValue(albumName);
 
-    if (!m_query->exec(QString("INSERT INTO CustomAutoImportPathTable3 (UID, FullPath, AlbumName) VALUES (%1, \"%2\", \"%3\")")
-                       .arg(UID).arg(path).arg(albumName))) {
+    if (!m_query->exec()) {
         return -1;
     }
 
@@ -1643,6 +1649,7 @@ void DBManager::removeTrashImgInfos(const QStringList &paths)
     for (int i = 0; i != paths.size(); ++i) {
         auto deletePath = utils::base::getDeleteFullPath(pathHashs[i], DBImgInfo::getFileNameFromFilePath(paths[i]));
         QFile::remove(deletePath);
+        utils::base::delTrashFile(paths[i]);
     }
 
     mutex.unlock();
@@ -1711,6 +1718,7 @@ QStringList DBManager::recoveryImgFromTrash(const QStringList &paths)
         if (QFile::rename(deletePath, recoveryName)) { //尝试正常恢复
             successedHashs.push_back(pathHashs[i]); //正常恢复成功
             succesedPaths.insert(pathHashs[i], recoveryName);
+            utils::base::delTrashFile(paths[i]); //同步删除回收站数据
         } else { //正常恢复失败，尝试恢复至内部路径
             if (!internalRecoveryDir.exists()) { //检查文件夹是否存在，不存在则创建
                 internalRecoveryDir.mkpath(internalRecoveryPath);
@@ -1739,6 +1747,7 @@ QStringList DBManager::recoveryImgFromTrash(const QStringList &paths)
             if (QFile::rename(deletePath, recoveryName)) {
                 successedHashs.push_back(pathHashs[i]); //恢复至内部路径
                 succesedPaths.insert(pathHashs[i], recoveryName);
+                utils::base::delTrashFile(paths[i]); //同步删除回收站数据
             } else { //TODO：极端特殊情况：使用内部恢复路径恢复失败
                 continue;
             }
