@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "imageenginethread.h"
 #include "imageengineapi.h"
 #include <dgiovolumemanager.h>
@@ -661,3 +645,42 @@ void RefreshTrashThread::runDetail()
         }
     }
 }
+
+SynRecycleBinToTrashThread::SynRecycleBinToTrashThread()
+{
+}
+
+SynRecycleBinToTrashThread::~SynRecycleBinToTrashThread()
+{
+}
+
+void SynRecycleBinToTrashThread::runDetail()
+{
+    int i = 0;
+    QStringList removepaths;
+    DBImgInfoList allTrashInfos;
+    DBImgInfo pinfo;
+
+    while (!bneedstop) {
+        removepaths.clear();
+
+        //遍历表:最近删除TrashTable3
+        allTrashInfos = DBManager::instance()->getAllTrashInfos_getRemainDays();
+        for (i = 0; i < allTrashInfos.size(); i++) {
+            pinfo = allTrashInfos.at(i);
+            if (!utils::base::isFileInTrash(pinfo.filePath)) {
+                //最近删除里的文件已不在回收站里，则删除
+                removepaths.append(pinfo.filePath);
+            }
+        }
+
+        //删除
+        if (0 < removepaths.length()) {
+            DBManager::instance()->removeTrashImgInfosNoSignal(removepaths);
+            emit sigTrashUpdate();
+        }
+
+        //休息一秒
+        QThread::sleep(1);
+    }
+}
