@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "mainwindow.h"
 #include "config.h"
 #include "dialogs/albumcreatedialog.h"
@@ -96,7 +80,8 @@ MainWindow::MainWindow()
     //性能优化，此句在构造时不需要执行，增加启动时间,放在showevent之后队列执行
     loadZoomRatio();
     m_bVector << true << true << true;
-
+    //主动设置wintitle
+    setWindowTitleInfo();
     //平板模式下屏蔽最大化最小化及关闭按钮
 #ifdef tablet_PC
     setWindowFlags(windowFlags() & ~(Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint));
@@ -106,6 +91,7 @@ MainWindow::MainWindow()
 MainWindow::~MainWindow()
 {
     emit dApp->signalM->sigPauseOrStart(false); //唤醒外设后台挂载,防止析构时线程挂起卡住页面无法退出
+    ImageEngineApi::instance()->StopSynRecycleBinToTrashThread();
     ImageEngineApi::instance()->close();
     QThreadPool::globalInstance()->clear();
     QThreadPool::globalInstance()->waitForDone();
@@ -225,6 +211,8 @@ void MainWindow::initConnections()
     connect(dApp->signalM, &SignalManager::ImportInterrupted, this, &MainWindow::onImportInterrupted);
     //恢复失败
     connect(dApp->signalM, &SignalManager::sigRestoreFailed, this, &MainWindow::onRestoreFailed);
+    //设置windowtitle
+    connect(ImageEngine::instance(), &ImageEngine::sigUpdateCollectBtn, this, &MainWindow::setWindowTitleInfo);
 }
 
 //初始化快捷键
@@ -1500,6 +1488,16 @@ void MainWindow::onRotatePic(const QString &path)
     }
 }
 
+void MainWindow::setWindowTitleInfo()
+{
+    if (m_imageViewer) {
+        if (m_imageViewer->getCurrentPath() != "" && windowTitle() != m_imageViewer->getCurrentPath()) {
+            qDebug() << __FUNCTION__ << "--" << m_imageViewer->getCurrentPath();
+            setWindowTitle(m_imageViewer->getCurrentPath());
+        }
+    }
+}
+
 //外部使用相册打开图片
 void MainWindow::onNewAPPOpen(qint64 pid, const QStringList &arguments)
 {
@@ -1593,6 +1591,8 @@ void MainWindow::onSigViewImage(const SignalManager::ViewInfo &info, OpenImgAddi
 
 void MainWindow::onHideImageView()
 {
+    //退出图片浏览，设置wintitle为空
+    setWindowTitle("");
     //返回界面删除
     deleteSaveImage();
     if (window()->isFullScreen()) {
