@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "baseutils.h"
 #include "imageutils.h"
 #include "application.h"
@@ -45,6 +29,7 @@
 #include <QTextStream>
 #include <QtMath>
 #include <QRegularExpression>
+#include <QSettings>
 
 #include <DApplication>
 #include <DDesktopServices>
@@ -437,6 +422,82 @@ bool trashFile(const QString &file)
     return true;
 }
 
+//彻底删除，删除回收站对应的文件
+bool delTrashFile(const QString &file)
+{
+    QString trashPath;
+    QString trashInfoPath;
+    QString trashFilesPath;
+
+    QString home = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    trashPath = home + "/.local/share/Trash";
+    trashInfoPath = trashPath + "/info";
+    trashFilesPath = trashPath + "/files";
+
+    QFileInfo originalInfo(file);
+    QString trashname = getNotExistsTrashFileName(originalInfo.fileName());
+
+    //restore filepath
+    QString fileRestorePath = QString(originalInfo.absoluteFilePath().toUtf8().toPercentEncoding("/"));
+
+    //查找info里所有与目标文件同名的文件列表
+    QDir dirTrashInfo(trashInfoPath);
+    QStringList trashInfofilelist = dirTrashInfo.entryList(QDir::NoDotAndDotDot | QDir::Files);
+    QStringList filterTrashInfofilelist = trashInfofilelist.filter(originalInfo.baseName() + ".");
+
+    //根据目标文件后缀名，做进一步筛选
+    filterTrashInfofilelist = filterTrashInfofilelist.filter("." + originalInfo.completeSuffix() + ".trashinfo");
+
+    //遍历trashinfo同名文件，验证目标文件是否在其中
+    for (int i = 0; i < filterTrashInfofilelist.size(); i++) {
+        QString filterTrashInfofilePath = trashInfoPath + "/" + filterTrashInfofilelist[i];
+        QSettings setting(filterTrashInfofilePath, QSettings::IniFormat);
+        QString path = setting.value("Trash Info/Path").toString();
+        if (path == fileRestorePath) {
+            std::remove(filterTrashInfofilePath.toStdString().c_str());
+            QString filepath = filterTrashInfofilelist[i];
+            filepath = trashFilesPath + "/" + filepath.remove(".trashinfo");
+            std::remove(filepath.toStdString().c_str());
+            return true;
+        }
+    }
+
+    return false;
+}
+
+bool isFileInTrash(const QString &file)
+{
+    QString trashPath;
+    QString trashInfoPath;
+    bool isFileIn = false;
+
+    QString home = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
+    trashPath = home + "/.local/share/Trash";
+    trashInfoPath = trashPath + "/info";
+
+    QFileInfo originalInfo(file);
+    // restore filepath
+    QString fileRestorePath = QString(originalInfo.absoluteFilePath().toUtf8().toPercentEncoding("/"));
+
+    //查找回收站里所有与目标文件同名的文件列表
+    QDir dirTrashInfo(trashInfoPath);
+    QStringList trashInfofilelist = dirTrashInfo.entryList(QDir::NoDotAndDotDot | QDir::Files);
+    QStringList filterTrashInfofilelist = trashInfofilelist.filter(originalInfo.baseName() + ".");
+
+    //遍历同名文件，验证目标文件是否在其中
+    for (int i = 0; i < filterTrashInfofilelist.size(); i++) {
+        QString filterTrashInfofilePath = trashInfoPath + "/" + filterTrashInfofilelist[i];
+        QSettings setting(filterTrashInfofilePath, QSettings::IniFormat);
+        QString path = setting.value("Trash Info/Path").toString();
+        if (path == fileRestorePath) {
+            isFileIn = true;
+            break;
+        }
+    }
+
+    return isFileIn;
+}
+
 QString getDeleteFullPath(const QString &hash, const QString &fileName)
 {
     //防止文件过长,采用只用hash的名称;
@@ -487,6 +548,62 @@ QList<QExplicitlySharedDataPointer<DGioMount>> getMounts_safe()
     return result;
 }
 
+QImage cheatScaled(const QImage &srcImg, int size, int side)
+{
+    QImage tImg;
+    if (side == 0) {//w
+        tImg = srcImg.scaledToWidth(size, Qt::SmoothTransformation);
+    } else {//h
+        tImg = srcImg.scaledToHeight(size, Qt::SmoothTransformation);
+    }
+    return tImg;
+}
+
+QImage getThumbnailFromImage(const QImage &srcImg, int size)
+{
+    QImage tImg(srcImg);
+
+    if (!tImg.isNull() && 0 != tImg.height() && 0 != tImg.width() && (tImg.height() / tImg.width()) < 10 && (tImg.width() / tImg.height()) < 10) {
+        bool cache_exist = false;
+        if (tImg.height() != size && tImg.width() != size) {
+            if (tImg.height() >= tImg.width()) {
+                cache_exist = true;
+                tImg = cheatScaled(tImg, size, 0);
+            } else if (tImg.height() <= tImg.width()) {
+                cache_exist = true;
+                tImg = cheatScaled(tImg, size, 1);
+            }
+        }
+        if (!cache_exist) {
+            if ((static_cast<float>(tImg.height()) / (static_cast<float>(tImg.width()))) > 3) {
+                tImg = cheatScaled(tImg, size, 0);
+            } else {
+                tImg = cheatScaled(tImg, size, 1);
+            }
+        }
+    }
+    if (!tImg.isNull()) {
+        int width = tImg.width();
+        int height = tImg.height();
+        if (abs((width - height) * 10 / width) >= 1) {
+            QRect rect = tImg.rect();
+            int x = rect.x() + width / 2;
+            int y = rect.y() + height / 2;
+            if (width > height) {
+                x = x - height / 2;
+                y = 0;
+                tImg = tImg.copy(x, y, height, height);
+            } else {
+                y = y - width / 2;
+                x = 0;
+                tImg = tImg.copy(x, y, width, width);
+            }
+        }
+    }
+
+    return tImg;
+}
+
 void multiLoadImage_helper(const QString &path)
 {
     QString srcPath = path;
@@ -511,43 +628,7 @@ void multiLoadImage_helper(const QString &path)
         }
     }
     //裁切
-    if (!tImg.isNull() && 0 != tImg.height() && 0 != tImg.width() && (tImg.height() / tImg.width()) < 10 && (tImg.width() / tImg.height()) < 10) {
-        bool cache_exist = false;
-        if (tImg.height() != 200 && tImg.width() != 200) {
-            if (tImg.height() >= tImg.width()) {
-                cache_exist = true;
-                tImg = tImg.scaledToWidth(200,  Qt::FastTransformation);
-            } else if (tImg.height() <= tImg.width()) {
-                cache_exist = true;
-                tImg = tImg.scaledToHeight(200,  Qt::FastTransformation);
-            }
-        }
-        if (!cache_exist) {
-            if ((static_cast<float>(tImg.height()) / (static_cast<float>(tImg.width()))) > 3) {
-                tImg = tImg.scaledToWidth(200,  Qt::FastTransformation);
-            } else {
-                tImg = tImg.scaledToHeight(200,  Qt::FastTransformation);
-            }
-        }
-    }
-    if (!tImg.isNull()) {
-        int width = tImg.width();
-        int height = tImg.height();
-        if (abs((width - height) * 10 / width) >= 1) {
-            QRect rect = tImg.rect();
-            int x = rect.x() + width / 2;
-            int y = rect.y() + height / 2;
-            if (width > height) {
-                x = x - height / 2;
-                y = 0;
-                tImg = tImg.copy(x, y, height, height);
-            } else {
-                y = y - width / 2;
-                x = 0;
-                tImg = tImg.copy(x, y, width, width);
-            }
-        }
-    }
+    tImg = getThumbnailFromImage(tImg, 200);
 
     ImageDataService::instance()->addImage(srcPath, tImg);
 }
