@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "widgets/albumlefttabitem.h"
 #include "dbmanager/dbmanager.h"
 #include "utils/baseutils.h"
@@ -139,6 +123,56 @@ void AlbumLeftTabItem::initUI()
 
     m_nameLabel = new DDlabel(pWidget);
     m_nameLabel->setGeometry(QRect(16, 0, 118, 40));
+    m_nameLabel->setAlignment(Qt::AlignVCenter);
+    QFont ft = DFontSizeManager::instance()->get(DFontSizeManager::T6);
+    ft.setFamily("SourceHanSansSC");
+    ft.setWeight(QFont::Medium);
+    m_nameLabel->setFont(ft);
+//    DPalette pa = DApplicationHelper::instance()->palette(m_nameLabel);
+//    pa.setBrush(DPalette::Text, pa.color(DPalette::ToolTipText));
+    m_nameLabel->setForegroundRole(DPalette::TextTitle);
+//    m_nameLabel->setPalette(pa);
+    // 设置标签不显示多文本
+    m_nameLabel->setTextFormat(Qt::PlainText);
+
+    m_pLineEdit->setParent(pWidget);
+    m_pLineEdit->setGeometry(QRect(0, 0, 120, 40));
+    if (COMMON_STR_RECENT_IMPORTED == m_albumNameStr) {
+        m_pLineEdit->setText(tr("Import"));
+    } else if (COMMON_STR_TRASH == m_albumNameStr) {
+        m_pLineEdit->setText(tr("Trash"));
+    } else if (COMMON_STR_FAVORITES == m_albumNameStr) {
+        m_pLineEdit->setText(tr("Favorites"));
+    } else {
+        m_pLineEdit->setText(m_albumNameStr);
+    }
+
+//    m_pLineEdit->setTextMargins(5,0,0,0);
+    m_pLineEdit->lineEdit()->setTextMargins(5, 0, 0, 0);
+//    m_pLineEdit->setAlignment(Qt::AlignVCenter| Qt::AlignLeft);
+    m_pLineEdit->lineEdit()->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
+    m_pLineEdit->setVisible(false);
+    m_pLineEdit->lineEdit()->setMaxLength(utils::common::ALBUM_NAME_MAX_LENGTH);
+    m_pLineEdit->setClearButtonEnabled(false);
+
+    pHBoxLayout->addWidget(pImageLabel, Qt::AlignVCenter);
+    pHBoxLayout->addWidget(pWidget, Qt::AlignVCenter);
+
+    m_unMountBtn = new MountExternalBtn(m_nameLabel);
+    //外部设备插入，需要添加卸载按钮
+    if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr || ALBUM_PATHTYPE_BY_U == m_albumTypeStr) {
+        QPixmap pixmapMount;
+        const int width = 24;
+        pixmapMount = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(width, width));
+        m_unMountBtn->setPixmap(pixmapMount);
+        pHBoxLayout->addWidget(m_unMountBtn); 
+
+        //调整m_nameLabel、m_pLineEdit宽度
+        QRect rect = m_nameLabel->geometry();
+        m_nameLabel->setGeometry(rect.x(), rect.y(), rect.width() - width - rect.x(), rect.height());
+        rect = m_pLineEdit->geometry();
+        m_pLineEdit->setGeometry(rect.x(), rect.y(), rect.width() - width, rect.height());
+    }
 
     QFontMetrics elideFont(m_nameLabel->font());
     if (COMMON_STR_RECENT_IMPORTED == m_albumNameStr) {
@@ -158,58 +192,11 @@ void AlbumLeftTabItem::initUI()
         AC_SET_ACCESSIBLE_NAME(m_nameLabel, Album_Fav_Label);
     } else {
         DFontSizeManager::instance()->bind(m_nameLabel, DFontSizeManager::T6, Qt::ElideRight);
-        m_nameLabel->Settext(m_albumNameStr);
+        m_nameLabel->Settext(elideFont.elidedText(m_albumNameStr, Qt::ElideRight, m_nameLabel->width()));
         AC_SET_OBJECT_NAME(m_nameLabel, m_albumNameStr);
         AC_SET_ACCESSIBLE_NAME(m_nameLabel, m_albumNameStr);
     }
-    m_nameLabel->setAlignment(Qt::AlignVCenter);
 
-    QFont ft = DFontSizeManager::instance()->get(DFontSizeManager::T6);
-    ft.setFamily("SourceHanSansSC");
-    ft.setWeight(QFont::Medium);
-    m_nameLabel->setFont(ft);
-
-//    DPalette pa = DApplicationHelper::instance()->palette(m_nameLabel);
-//    pa.setBrush(DPalette::Text, pa.color(DPalette::ToolTipText));
-    m_nameLabel->setForegroundRole(DPalette::TextTitle);
-//    m_nameLabel->setPalette(pa);
-
-    m_pLineEdit->setParent(pWidget);
-    m_pLineEdit->setGeometry(QRect(0, 0, 120, 40));
-    if (COMMON_STR_RECENT_IMPORTED == m_albumNameStr) {
-        m_pLineEdit->setText(tr("Import"));
-    } else if (COMMON_STR_TRASH == m_albumNameStr) {
-        m_pLineEdit->setText(tr("Trash"));
-    } else if (COMMON_STR_FAVORITES == m_albumNameStr) {
-        m_pLineEdit->setText(tr("Favorites"));
-    } else {
-        m_pLineEdit->setText(m_albumNameStr);
-    }
-
-//    m_pLineEdit->setTextMargins(5,0,0,0);
-    m_pLineEdit->lineEdit()->setTextMargins(5, 0, 0, 0);
-//    m_pLineEdit->setAlignment(Qt::AlignVCenter| Qt::AlignLeft);
-    m_pLineEdit->lineEdit()->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
-
-    m_pLineEdit->setVisible(false);
-//    m_pLineEdit->setMaxLength(64);
-    m_pLineEdit->lineEdit()->setMaxLength(64);
-
-    m_pLineEdit->setClearButtonEnabled(false);
-
-    pHBoxLayout->addWidget(pImageLabel, Qt::AlignVCenter);
-    pHBoxLayout->addWidget(pWidget, Qt::AlignVCenter);
-
-
-    m_unMountBtn = new MountExternalBtn(m_nameLabel);
-    //外部设备插入，需要添加卸载按钮
-    if (ALBUM_PATHTYPE_BY_PHONE == m_albumTypeStr || ALBUM_PATHTYPE_BY_U == m_albumTypeStr) {
-        QPixmap pixmapMount;
-        pixmapMount = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(24, 24));
-        m_unMountBtn->setPixmap(pixmapMount);
-        pHBoxLayout->addWidget(m_unMountBtn);
-        //m_unMountBtn->move(92, 9);
-    }
     this->setLayout(pHBoxLayout);
 }
 
@@ -249,7 +236,8 @@ void AlbumLeftTabItem::onCheckNameValid()
         //由于m_nameLabel->text()的值还是原来的值，此处修改为直接使用上面获取的lineedit的值
         newNameStr = AlbumCreateDialog::getNewAlbumName(newNameStr);
         QFontMetrics elideFont(m_nameLabel->font());
-        m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
+        //m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
+        m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, m_nameLabel->width()));
         m_nameLabel->oldstr = newNameStr;
         QFont ft;
         ft.setPixelSize(14);
@@ -264,7 +252,8 @@ void AlbumLeftTabItem::onCheckNameValid()
         emit dApp->signalM->sigUpdataAlbumRightTitle(m_albumNameStr);
     } else if (OPE_MODE_ADDNEWALBUM == m_opeMode) {
         QFontMetrics elideFont(m_nameLabel->font());
-        m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
+        //m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
+        m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, m_nameLabel->width()));
         m_nameLabel->oldstr = newNameStr;
         QFont ft;
         ft.setPixelSize(14);
@@ -431,3 +420,9 @@ void AlbumLeftTabItem::newAlbumStatus()
     pImageLabel->setPixmap(pixmap);
     m_nameLabel->setForegroundRole(DPalette::HighlightedText);
 }
+
+//解决bug165483,屏蔽该函数
+void AlbumLeftTabItem::mouseReleaseEvent(QMouseEvent *e)
+{
+    Q_UNUSED(e)
+}
