@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Technology Co., Ltd.
- *
- * Author:     ZhangYong <zhangyong@uniontech.com>
- *
- * Maintainer: ZhangYong <ZhangYong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef BATCHOPERATEWIDGET_H
 #define BATCHOPERATEWIDGET_H
 
@@ -92,6 +76,8 @@ signals:
     void signalBatchSelectChanged(bool isBatchSelect);
     //取消全选时通知标题栏刷新
     void sigCancelAll(bool cancel);
+    //筛选条件按钮宽度变化信号
+    void sigFilterBtnWidthChanged(int width);
 public slots:
     //批量操作状态改变
     void sltBatchSelectChanged();
