@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "expansionmenu.h"
 #include "expansionpanel.h"
 
@@ -113,6 +117,12 @@ bool FilterWidget::eventFilter(QObject *obj, QEvent *event)
     return QWidget::eventFilter(obj, event);
 }
 
+void FilterWidget::resizeEvent(QResizeEvent *e)
+{
+    sigWidthChanged(this->width());
+    QWidget::resizeEvent(e);
+}
+
 
 ExpansionMenu::ExpansionMenu(QWidget *parent)
     : QObject(parent)
