@@ -1,6 +1,61 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="id">
+<context>
+    <name></name>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished">Hapus</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="unfinished">Tampilan slide</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="unfinished">Ekspor</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="unfinished">Duplikat</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="unfinished">Putar searah jarum jam</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="unfinished">Putar berlawanan jarum jam</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="unfinished">Tampilkan di manajer file</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="unfinished">Informasi Foto</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="unfinished">Kembalikan</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -64,18 +119,10 @@
         <source>Or drag photos here</source>
         <translation>Atau arahkan foto disini</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto(foto-foto)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Impor Semua</translation>
     </message>
-    <message>
-        <source>The photos will be permanently deleted after the days shown on it</source>
-        <translation type="vanished">Foto-foto akan dihapus secara permanen setelah hari-hari yang tertera</translation>
-    </message>
     <message>
         <source>Import to:</source>
         <translation>Impor ke:</translation>
@@ -112,16 +159,12 @@
         <source>Ignore</source>
         <translation>Abaikan</translation>
     </message>
-    <message>
-        <source>Loading photos, please wait...</source>
-        <translation type="vanished">Sedang memuat foto, mohon menunggu</translation>
-    </message>
     <message>
         <source>Loading...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -245,13 +288,6 @@
         <translation>Batal</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Informasi Foto</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -263,13 +299,6 @@
         <translation>Sedang memulihkan...</translation>
     </message>
 </context>
-<context>
-    <name>ImageLoadFromLocalThread</name>
-    <message>
-        <source>days</source>
-        <translation type="vanished">hari</translation>
-    </message>
-</context>
 <context>
     <name>ImgDeleteDialog</name>
     <message>
@@ -284,10 +313,6 @@
         <source>Are you sure you want to delete this photo from the album?</source>
         <translation>Apakah anda yakin ingin menghapus foto ini dari album?</translation>
     </message>
-    <message>
-        <source>Are you sure you want to delete %1 photos from albums?</source>
-        <translation type="vanished">Apakah anda yakin ingin menghapus %1 foto dari album?</translation>
-    </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
         <translation type="unfinished">
@@ -322,8 +347,8 @@
         <translation>Detail</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Informasi Foto</translation>
+        <source>Image info</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -409,17 +434,6 @@
         <translation>Album Baru</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the image</source>
-        <translation type="vanished">Anda tidak punya izin untuk melihat gambar ini</translation>
-    </message>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -521,10 +535,6 @@
         <source>Albums</source>
         <translation>Album</translation>
     </message>
-    <message>
-        <source>Photo info</source>
-        <translation type="vanished">Informasi Foto</translation>
-    </message>
     <message>
         <source>Exit fullscreen/slideshow</source>
         <translation>Keluar mode layarpenuh/slideshow</translation>
@@ -537,22 +547,10 @@
         <source>View</source>
         <translation>View</translation>
     </message>
-    <message>
-        <source>Export</source>
-        <translation type="vanished">Ekspor</translation>
-    </message>
-    <message>
-        <source>Import</source>
-        <translation type="vanished">Impor</translation>
-    </message>
     <message>
         <source>Select all</source>
         <translation>Pilih semua</translation>
     </message>
-    <message>
-        <source>Delete photo/album</source>
-        <translation type="vanished">Hapus foto/album</translation>
-    </message>
     <message>
         <source>Zoom in</source>
         <translation>Perbesar</translation>
@@ -577,14 +575,6 @@
         <source>Settings</source>
         <translation>Pengaturan</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Impor foto</translation>
-    </message>
-    <message>
-        <source>Import Photos</source>
-        <translation type="vanished">Impor Foto</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Sedang mengimpor...</translation>
@@ -617,6 +607,10 @@
         <source>Photo/Video info</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -701,8 +695,8 @@
         <translation>Tag</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nama foto</translation>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -733,10 +727,6 @@
         <source>%1/%2/%3</source>
         <translation>%1/%2/%3</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation type="vanished">%1 foto(foto-foto)</translation>
-    </message>
     <message>
         <source>Imported on</source>
         <translation>Telah diimpor di</translation>
@@ -889,39 +879,8 @@
         </translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Jeda</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Putar</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Keluar</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Sebelumnya</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Selanjutnya</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
-    <message>
-        <source>Importing photos: &apos;%1&apos;</source>
-        <translation type="vanished">Sedang mengimpor foto: &apos;%1&apos;</translation>
-    </message>
-    <message>
-        <source>Exporting photos: &apos;%1&apos;</source>
-        <translation type="vanished">Sedang meekspor foto: &apos;%1&apos;</translation>
-    </message>
     <message>
         <source>1 photo</source>
         <translation type="unfinished"></translation>
@@ -951,49 +910,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Kembali</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Sebelumnya</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Selanjutnya</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Ukuran 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Sesuaikan dengan jendela</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Putar berlawanan jarum jam</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Putar searah jarum jam</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Hapus</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favorit</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Batal Favorit</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -1077,17 +993,6 @@
         <translation type="unfinished">hari</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Tidak ditemukan file gambar</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Foto tidak ditemukan</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1175,10 +1080,6 @@
         <source>Sampling</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Date modified</source>
         <translation type="unfinished">Tanggal diubah</translation>
@@ -1207,84 +1108,9 @@
         <source>Date captured</source>
         <translation type="unfinished">Tanggal mengambil foto</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Tambahkan ke album</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Tampilan slide</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Keluar mode layar penuh</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Layar penu</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Duplikat</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Hapus</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Tampilkan jendela navigasi</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Sembunyikan jendela navigasi</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Putar searah jarum jam</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Putar berlawanan jarum jam</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Atur sebagai Wallpaper</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Tampilkan di manajer file</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Ekspor</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Batal Favorit</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Informasi Foto</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Hapus dari album</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Favorit</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Album Baru</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Cetak</translation>
+        <source>Name</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
