@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Обриши</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Цео екран</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Покретни приказ</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Извези</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Копирај</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">У омиљено</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Ротирај удесно</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Ротирај улево</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Постави као позадину</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Прикажи у управнику података</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Подаци слике</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="vanished">Подаци видеа</translation>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Врати</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Или првуци слике овде</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 слика(е)</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Увези све</translation>
@@ -111,8 +162,8 @@
         <translation>Учитавање...</translation>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
-        <translation>Датотеке ће бити трајно обрисане након датума приказаног на њима</translation>
+        <source>The files will be permanently deleted after the days shown on them</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -201,6 +252,25 @@
         <translation>већ постоји. Желите ли да замените?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Откажи</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Подаци слике</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,7 +328,7 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Заиста желите да обришете ову слику из албума?</translation>
+        <translation type="vanished">Заиста желите да обришете ову слику из албума?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
@@ -283,6 +346,38 @@
         <source>Are you sure you want to delete %n items from albums?</source>
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ImgInfoDialog</name>
@@ -295,8 +390,8 @@
         <translation>Детаљи</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Подаци слике</translation>
+        <source>Image info</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Све слике и видео записи</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation>Нису пронађене слике или видео записи</translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Нови албум</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation>Немате дозволу да прегледате датотеку</translation>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Подешавања</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Увези слику</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Увоз...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Ознака</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Име слике</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Паузирај</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Пусти</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Изађи</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Претходно</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Следеће</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Назад</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Претходно</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Следеће</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>1:1 Размера</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Уклопи у прозор</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Ротирај улево</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Ротирај удесно</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Обриши</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>У омиљено</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Из омиљеног</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>дана</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Нису пронађене датотеке са сликама</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Слика није пронађена</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Датум измене</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Датум усликавања</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Додај у албум</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Покретни приказ</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Напусти цео екран</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Цео екран</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Копирај</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Обриши</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Прикажи навигациони прозор</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Сакриј навигациони прозор</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Ротирај удесно</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Ротирај улево</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Постави као позадину</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Прикажи у управнику података</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Извези</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Из омиљеног</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Подаци слике</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Уклоини из албума</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>У омиљено</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Нови албум</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Штампај</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
